/*
 * Sonar, entreprise quality control tool.
 * Copyright (C) 2007-2008 Hortis-GRC SA
 * mailto:be_agile HAT hortis DOT ch
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with {library}; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package ch.hortis.sonar;

import java.io.File;
import java.util.Properties;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class SonarProperties {

  private final static Logger log = LoggerFactory.getLogger(SonarProperties.class.getName());
  
  public final static String SONAR_ROOT_SYS_PROP = "sonar.root";
  private static String sonarRootPath;
  private static String testFilePath = "conf/jetty-env.xml";
  
  public static String getSonarRoot() throws Exception {
    if ( sonarRootPath == null ) {
      Properties p = System.getProperties();
      sonarRootPath = (String) p.get(SONAR_ROOT_SYS_PROP);
      if ( sonarRootPath == null ) {
        sonarRootPath = "../"; 
      }
      File file = new File( sonarRootPath );
      sonarRootPath = file.getCanonicalPath();
      
      if (!isValidRoot()) {
        throw new Exception("Cannot find the root path of Sonar (" + sonarRootPath + ").\n" +
        		"Verify the system property 'sonar.root' containing the root of the Sonar's application.");        
      }
      log.info( "Sonar Root resolved to " + sonarRootPath );
    } 
    return sonarRootPath;
  }
  
  private static boolean isValidRoot(){
    File testFile = new File(sonarRootPath + "/" + testFilePath);
    if (testFile.isFile()) {
      return true;
    }    
    return false;
  }
}
