/*
 * Sonar, entreprise quality control tool.
 * Copyright (C) 2007-2008 Hortis-GRC SA
 * mailto:be_agile HAT hortis DOT ch
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with {library}; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package ch.hortis.sonar.model;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.JoinTable;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;

import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.commons.lang.builder.HashCodeBuilder;
import org.apache.commons.lang.builder.ToStringBuilder;

@Entity
@Table(name = "file_measures")
public class FileMeasure extends MetricMeasure implements Serializable, WithFile, Collectable {
  
  private static final long serialVersionUID = -8547266020380372485L;

  @Id
  @Column(name = "id")
  @SequenceGenerator(name= "FILE_MEASURES_SEQ", sequenceName = "FILE_MEASURES_SEQ")
  @GeneratedValue(strategy = GenerationType.AUTO, generator = "FILE_MEASURES_SEQ")
  private Integer id;

  @ManyToOne(optional=false,fetch = FetchType.LAZY, cascade = {CascadeType.MERGE, CascadeType.PERSIST, CascadeType.REFRESH})
  @JoinColumn(name = "file_id", updatable = false, nullable = false)
  private File file;

  @OneToMany(fetch = FetchType.LAZY, cascade = {CascadeType.MERGE, CascadeType.PERSIST, CascadeType.REMOVE})
  @JoinTable(
      name = "file_measures_parameters",
      joinColumns = {@JoinColumn(name = "file_measure_id")},
      inverseJoinColumns = @JoinColumn(name = "parameter_id"))
  private List<Parameter> parameters;
  
  public FileMeasure() {
  }
  
  public FileMeasure( Snapshot snapshot, Metric metric, Double value, File file ) {
    super.snapshot = snapshot;
    super.metric = metric;
    super.value = value;
    this.file = file;
    this.parameters = new ArrayList<Parameter>();
  }
  
  public Integer getId() {
    return id;
  }

  public void setId( Integer id ) {
    this.id = id;
  }

  public File getFile() {
    return file;
  }

  public void setFile(File file) {
    this.file = file;
  }

  public List<Parameter> getParameters() {
    return parameters;
  }

  public void setParameters( List<Parameter> parameters ) {
    this.parameters = parameters;
  }

  public void addParameter( String key, Double value ) {
    addParameter(key, value, null);
  }

  public void addParameter( String key, Double value, Double value2 ) {
    if ( parameters == null ) {
      parameters = new ArrayList<Parameter>();
    }
    parameters.add( new Parameter( key, value, value2 ) );
  }

  public Parameter getParameter( String key ) {
    for (Parameter param : getParameters()) {
      if (param.getKey().equals( key )) {
        return param;
      }
    }
    return null;
  }

  public boolean equals(Object obj) {
    if (!(obj instanceof FileMeasure)) {
      return false;
    }
    if (this == obj) {
      return true;
    }
    FileMeasure other = (FileMeasure) obj;
    return new EqualsBuilder()
        .append(id, other.getId()).isEquals();
  }

  public int hashCode() {
    return new HashCodeBuilder().append(id).toHashCode();
  }

  public String toString() {
    return new ToStringBuilder(this).
       append("id", id).
       append("value", value).
       append("metric", metric).
       append("file", file).
       toString();
  }
}