/*
 * Sonar, entreprise quality control tool.
 * Copyright (C) 2007-2008 Hortis-GRC SA
 * mailto:be_agile HAT hortis DOT ch
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with {library}; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package ch.hortis.sonar.model;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.Lob;
import javax.persistence.OneToOne;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;

import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.commons.lang.builder.HashCodeBuilder;

@Entity
@Table(name = "file_sources")
public class FileSource implements WithFile {

  @Id
  @Column(name = "id")
  @SequenceGenerator(name= "FILE_SOURCES_SEQ", sequenceName = "FILE_SOURCES_SEQ")
  @GeneratedValue(strategy = GenerationType.AUTO, generator = "FILE_SOURCES_SEQ")
  private Integer id;

  @Lob
  @Column(name = "source", updatable = true, nullable = true, length=16777215)
  private String source;

  @OneToOne(fetch = FetchType.LAZY)
  @JoinColumn(name = "file_id", updatable = false, nullable = false)
  protected File file;

  public FileSource(String source) {
    setSource(source);
  }

  public FileSource() {
  }

  public File getFile() {
    return file;
  }

  public void setFile(File file) {
    this.file = file;
  }

  public Integer getId() {
    return id;
  }

  public void setId(Integer id) {
    this.id = id;
  }

  public String getSource() {
    return source;
  }

  public void setSource(String source) {
    this.source = source;
  }
  
  public boolean equals(Object obj) {
    if (!(obj instanceof FileSource)) {
      return false;
    }
    if (this == obj) {
      return true;
    }
    FileSource other = (FileSource) obj;
    return new EqualsBuilder()
        .append(id, other.getId()).isEquals();
  }

  public int hashCode() {
    return new HashCodeBuilder(17, 37).
        append(id).toHashCode();
  }

}
