/*
 * Sonar, entreprise quality control tool.
 * Copyright (C) 2007-2008 Hortis-GRC SA
 * mailto:be_agile HAT hortis DOT ch
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with {library}; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package ch.hortis.sonar.model;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.JoinTable;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;

import org.apache.commons.lang.StringUtils;
import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.commons.lang.builder.HashCodeBuilder;

@Entity
@Table(name = "rule_failures")
public class RuleFailure implements Serializable, WithFile, Collectable {

  private static final long serialVersionUID = 6573631005994829171L;
  
  public static final int MESSAGE_COLUMN_SIZE = 500;

  @Id
  @Column(name = "id")
  @SequenceGenerator(name= "RULE_FAILURES_SEQ", sequenceName = "RULE_FAILURES_SEQ")
  @GeneratedValue(strategy = GenerationType.AUTO, generator = "RULE_FAILURES_SEQ")
  private Integer id;

  @ManyToOne(fetch = FetchType.LAZY)
  @JoinColumn(name = "snapshot_id")
  private Snapshot snapshot;

  @ManyToOne(fetch = FetchType.LAZY, cascade = {CascadeType.MERGE, CascadeType.PERSIST, CascadeType.REFRESH})
  @JoinColumn(name = "file_id",updatable = true, nullable = true)
  private File file;

  @ManyToOne(fetch = FetchType.LAZY)
  @JoinColumn(name = "rule_id")
  private Rule rule;

  @OneToMany(fetch = FetchType.LAZY, cascade = {CascadeType.PERSIST, CascadeType.MERGE, CascadeType.REMOVE})
  @JoinTable(
      name = "rule_failures_parameters",
      joinColumns = {@JoinColumn(name = "rule_failure_id")},
      inverseJoinColumns = @JoinColumn(name = "parameter_id"))
  private List<Parameter> parameters;

  @Column(name = "failure_level", updatable = false, nullable = false)
  @Enumerated(EnumType.ORDINAL)
  private RuleFailureLevel failureLevel;

  @Column(name = "message", updatable = false, nullable = true, length = MESSAGE_COLUMN_SIZE)
  private String message;

  public RuleFailure() {
  }

  public RuleFailure(File file, Rule rule, RuleFailureLevel level) {
    this.file = file;
    this.rule = rule;
    this.failureLevel = level;
    this.parameters = new ArrayList<Parameter>();
  }

  public String getMessage() {
    return message;
  }

  public void setMessage( String message ) {
    this.message = StringUtils.abbreviate(message, MESSAGE_COLUMN_SIZE);
  }

  public Integer getId() {
    return id;
  }

  public void setId( Integer id ) {
    this.id = id;
  }

  public Snapshot getSnapshot() {
    return snapshot;
  }

  public void setSnapshot( Snapshot snapshot) {
    this.snapshot = snapshot;
  }

  public RuleFailureLevel getLevel() {
    return failureLevel;
  }

  public void setLevel( RuleFailureLevel level ) {
    this.failureLevel = level;
  }


  public File getFile() {
    return file;
  }

  public void setFile( File file ) {
    this.file = file;
  }

  public Rule getRule() {
    return rule;
  }

  public void setRule( Rule rule ) {
    this.rule = rule;
  }

  public List<Parameter> getParameters() {
    return parameters;
  }

  public void setParameters( List<Parameter> parameters ) {
    this.parameters = parameters;
  }

  public void addParameter( String key, Double value ) {
    addParameter(key, value, null);
  }

  public void addParameter( String key, Double value, Double value2 ) {
    if ( parameters == null ) {
      parameters = new ArrayList<Parameter>();
    }
    parameters.add( new Parameter( key, value, value2 ) );
  }

  public Parameter getParameter( String key ) {
    for (Parameter param : parameters) {
      if (param.getKey().equals( key )) {
        return param;
      }
    }
    return null;
  }

  public boolean equals(Object obj) {
    if (!(obj instanceof RuleFailure)) {
      return false;
    }
    if (this == obj) {
      return true;
    }
    RuleFailure other = (RuleFailure) obj;
    return new EqualsBuilder()
        .append(id, other.getId()).isEquals();
  }

  public int hashCode() {
    return new HashCodeBuilder(17, 37).
        append(id).toHashCode();
  }
  
}
