/*
 * Sonar, entreprise quality control tool.
 * Copyright (C) 2007-2008 Hortis-GRC SA
 * mailto:be_agile HAT hortis DOT ch
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with {library}; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package ch.hortis.sonar.service;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.persistence.EntityManager;
import java.util.ArrayList;
import java.util.List;

public abstract class Service {
  protected final EntityManager manager;
  protected final Logger log;

  public Service(EntityManager manager) {
    this.manager = manager;
    this.log = LoggerFactory.getLogger(this.getClass().getName());
  }

  public static final List<Service> getAllServices(EntityManager manager) {
    List<Service> services = new ArrayList<Service>();
    services.add(new MetricService(manager));
    services.add(new MavenProjectService(manager));
    services.add(new ProjectMeasureService(manager));
    services.add(new RuleFailureService(manager));
    services.add(new RulesService(manager));
    services.add(new SnapshotGroupService(manager));
    services.add(new PropertiesService(manager));
    services.add(new ActiveRulesService(manager));
    return services;
  }
}